pub struct HeapId(/* private fields */);Expand description
Identifier of a VM heap.
EraVM docs sometimes refer to heaps as heap pages; docs in these crate don’t to avoid confusion with internal heap structure.
Implementations
Sourceimpl HeapId
impl HeapId
Sourcepub const FIRST_CALLDATA: Self
pub const FIRST_CALLDATA: Self
Identifier of the calldata heap used by the first executed program (i.e., the bootloader).
Sourcepub const FIRST: Self
pub const FIRST: Self
Identifier of the heap used by the first executed program (i.e., the bootloader).