pub struct L2ToL1Log {
pub key: U256,
pub value: U256,
pub is_service: bool,
pub address: H160,
pub shard_id: u8,
pub tx_number: u16,
}Expand description
L2-to-L1 log emitted by EraVM.
Fields
key: U256Log key.
value: U256Log value.
is_service: boolIs this a service log?
address: H160Address of the contract that has emitted this log.
shard_id: u8Shard identifier (currently, always set to 0).
tx_number: u160-based index of a transaction that has emitted this event.